"
GsTestResult is the GemStone-specific refinement of the SUnit TestResult class.
"
Class {
	#name : 'GsTestResult',
	#superclass : 'TestResult',
	#gs_options : [
		'instancesNonPersistent'
	],
	#category : nil
}

{ #category : 'Accessing' }
GsTestResult class >> failureLogFile [
  ^ SessionTemps current at: #GsTestResultFailuresLog ifAbsentPut:[ | f |
     f := GsFile openAppendOnServer:'SUnitFailures.log' .
     f ifNil:[ Error signal:'open failed', GsFile serverErrorString ].
     f
  ]

]

{ #category : 'Adding' }
GsTestResult >> addError: aTestCase [
  "nil pause . ""uncomment to debug test framework"
  self logFailure: aTestCase .
  super addError: aTestCase printString  "don't keep aTestCase alive in memory"

]

{ #category : 'Adding' }
GsTestResult >> addFailure: aTestCase [
  "nil pause . ""uncomment to debug test framework"
  self logFailure: aTestCase .
  super addFailure: aTestCase printString  "don't keep aTestCase alive in memory"

]

{ #category : 'Adding' }
GsTestResult >> addPass: aTestCase [
  ^self passed add: aTestCase printString  "don't keep aTestCase alive in memory"
]

{ #category : 'Accessing' }
GsTestResult >> passed [
   passed ifNil: [passed := NonPersistentArray new ].
   ^ passed
]

{ #category : 'Accessing' }
GsTestResult >> defects [
 ^ self failures

]

{ #category : 'Accessing' }
GsTestResult >> errors [
  "One list in order of occurrance"
  ^ self failures

]

{ #category : 'Accessing' }
GsTestResult >> failures [
   failures ifNil: [failures := NonPersistentArray new ].
   ^failures

]

{ #category : 'Logging' }
GsTestResult >> logFailure: aTestCase [
 (System gemEnvironmentVariable: 'resultdir') ifNotNil:[:path |  | idx dir str ver |
    self class failureLogFile ifNotNil:[ :f |
      idx := path indexOfLastByte: $/ codePoint startingAt: path size .
      dir := path copyFrom: idx + 1 to: path size .
      ver := System _gemVersion .
      idx := ver indexOf: $, startingAt: 1 .
      ver := ver copyFrom: 1 to: idx - 1 .
      str := ver,', ', System hostname, ', ', dir , ', ', aTestCase printString .
      f nextPutAll: str lf ; flush .
    ].
 ] ifNil:[ "assume interactive, don't log" ].

]

{ #category : 'Running' }
GsTestResult >> runCase: aTestCase [
" | debugBlk |
uncomment and enable to get an SUnit.log file of send...debug: of all the test cases"
" (SessionTemps current at: #Ernie_collectCases otherwise: nil) ifNotNil:[
   GsTestCase logCr: aTestCase class name , ' debug: ', aTestCase selector printString.
   ^ self
 ]."
" debugBlk := [ :ex |
   (SessionTemps current at: #Ernie_debugIgnoreErrNum otherwise: nil) ifNotNil:[:n |
     ex gsNumber == n ifFalse:[ nil pause ].
   ].
 ]. "
 (self class excludeInSoloSession: aTestCase) ifTrue:[
   GsTestCase logCr: aTestCase printString , ' -  Excluding in Solo session'.
   ^ self .
 ].
 [
   [  aTestCase runCase.
      self passed add: aTestCase.
   ] on: self class failure do: [:ex |
     "debugBlk value: ex . "
     self addFailure: aTestCase.
     GsTestCase logCr: 'fail - ' , ex description asString.
     self
   ].
 ] on: (Error, Notification) do: [:ex |
   ex class defaultHandlers size > 0 ifTrue:[ ex pass ].
		"debugBlk value: ex  ."
		self addError: aTestCase.
		GsTestCase logCr: 'error - ' , ex description asString .
	  GsTestCase isDebug ifFalse:[
           GsTestCase logCr:'------------------------------(
' , (GsProcess stackReportToLevel:300) , '
------------------------------)'.
   ].
   self
 ].

]

{ #category : 'Excluding' }
GsTestResult class >> excludeInSoloSession: aTestCase [

"Overwritten by Ernie"

^ false

]
